@@ -1,4 +1,8 @@
 package RapidApp::Error::CustomPrompt;
+
+use strict;
+use warnings;
+
 die "Use RapidApp::Responder::CustomPrompt instead of RapidApp::Error::CustomPrompt";
 
 1;
