@@ -447,6 +447,9 @@ Ext.ux.AutoPanel = Ext.extend(Ext.Panel, {
   },
 
   setBodyConf: function(conf,thisEl,clear) {
+    // Always attempt to find and remove loading-indicator
+    this.purgeLoadingIndicator();
+  
     thisEl = thisEl || this.getEl();
     if(this.items.getCount() > 0) { this.removeAll(true); }
     
@@ -498,6 +501,11 @@ Ext.ux.AutoPanel = Ext.extend(Ext.Panel, {
     this.setBodyConf(opt.bodyConf,this.getEl());
   },
   
+  purgeLoadingIndicator: function() {
+    var loadEl = this.getEl().child('div.loading-indicator');
+    if(loadEl) { loadEl.remove(); }
+  },
+  
   reload: function() {
     // Call removeAll now so that any listeners associated with remove/destroy can
     // be called early (removeAll also gets called during the load process later).
@@ -515,9 +523,19 @@ Ext.ux.AutoPanel = Ext.extend(Ext.Panel, {
     // TODO: hook into the guts of this process to support
     // actually cancelling the reload. This would need to be done by calling and
     // testing the result of 'beforeremove'
-
-    // And then purge any listeners for a clean, fresh start. 
-    this.purgeListeners();
+    
+    // NEW/Updated:
+    // Clear *only* 'beforeremove' events -- we can't call purgeListeners()
+    // because it breaks things like resize events. We only really need to
+    // escape 'beforeremove' because, again, its too late at this point to abort
+    // the remove, which is what beforeremove is for (as discussed above)
+    var befRem = this.events.beforeremove;
+    if(befRem && typeof befRem == 'object') {
+      befRem.clearListeners();
+    }
+    
+    // Purge any child listeners for good measure (probably not needed)
+    this.items.each(function(itm) { itm.purgeListeners(); });
 
     // Now call load using the same/original autoLoad config:
     this.load(this.autoLoad);
